diff --git a/core/modules/breakpoint/breakpoint.breakpoints.yml b/core/modules/breakpoint/breakpoint.breakpoints.yml
new file mode 100644
index 0000000..f46f6e9
--- /dev/null
+++ b/core/modules/breakpoint/breakpoint.breakpoints.yml
@@ -0,0 +1,7 @@
+breakpoint.all.viewport_sizing:
+  label: Viewport Sizing
+  mediaQuery: ''
+  weight: 0
+  multipliers:
+    - 1x
+  group: All Viewports
diff --git a/core/modules/breakpoint/src/Tests/BreakpointDiscoveryTest.php b/core/modules/breakpoint/src/Tests/BreakpointDiscoveryTest.php
index b39c2a8..642d87b 100644
--- a/core/modules/breakpoint/src/Tests/BreakpointDiscoveryTest.php
+++ b/core/modules/breakpoint/src/Tests/BreakpointDiscoveryTest.php
@@ -188,6 +188,7 @@ public function testModuleBreakpoints() {
    */
   public function testBreakpointGroups() {
     $expected = array(
+      'breakpoint.all' => 'All Viewports',
       'bartik' => 'Bartik',
       'breakpoint_module_test' => 'Breakpoint test module',
       'breakpoint_theme_test' => 'Breakpoint test theme',
diff --git a/core/modules/image/config/install/image.style.gigantic.yml b/core/modules/image/config/install/image.style.gigantic.yml
new file mode 100644
index 0000000..7ffe90b
--- /dev/null
+++ b/core/modules/image/config/install/image.style.gigantic.yml
@@ -0,0 +1,11 @@
+name: gigantic
+label: 'Gigantic (1920x1920)'
+effects:
+  9b311dd1-0351-45a1-9500-cd069e4670cb:
+    id: image_scale
+    data:
+      width: 1920
+      height: 1920
+      upscale: false
+    weight: 3
+    uuid: 9b311dd1-0351-45a1-9500-cd069e4670cb
diff --git a/core/modules/image/config/install/image.style.huge.yml b/core/modules/image/config/install/image.style.huge.yml
new file mode 100644
index 0000000..95a8c92
--- /dev/null
+++ b/core/modules/image/config/install/image.style.huge.yml
@@ -0,0 +1,11 @@
+name: huge
+label: 'Huge (960x960)'
+effects:
+  04caae9a-fa3e-4ea6-ae09-9c26aec7d308:
+    id: image_scale
+    data:
+      width: 960
+      height: 960
+      upscale: false
+    weight: 1
+    uuid: 04caae9a-fa3e-4ea6-ae09-9c26aec7d308
diff --git a/core/modules/responsive_image/config/install/responsive_image.styles.narrow.yml b/core/modules/responsive_image/config/install/responsive_image.styles.narrow.yml
new file mode 100644
index 0000000..c7aa6e1
--- /dev/null
+++ b/core/modules/responsive_image/config/install/responsive_image.styles.narrow.yml
@@ -0,0 +1,24 @@
+uuid: 8eb79e19-da57-4bd3-8304-4e0b5a147276
+status: true
+dependencies:
+  config:
+    - image.style.huge
+    - image.style.large
+    - image.style.medium
+  module:
+    - breakpoint
+id: narrow
+label: Narrow
+image_style_mappings:
+  -
+    breakpoint_id: breakpoint.all.viewport_sizing
+    multiplier: 1x
+    image_mapping_type: sizes
+    image_mapping:
+      sizes: '(min-width: 1290px) 325px, (min-width: 851px) 25vw, (min-width: 560px) 50vw, 100vw'
+      sizes_image_styles:
+        - huge
+        - large
+        - medium
+breakpoint_group: All Viewports
+fallback_image_style: medium
diff --git a/core/modules/responsive_image/config/install/responsive_image.styles.wide.yml b/core/modules/responsive_image/config/install/responsive_image.styles.wide.yml
new file mode 100644
index 0000000..e4880ae
--- /dev/null
+++ b/core/modules/responsive_image/config/install/responsive_image.styles.wide.yml
@@ -0,0 +1,26 @@
+uuid: 5cffd3ef-5656-4446-b200-b771d8076568
+status: true
+dependencies:
+  config:
+    - image.style.gigantic
+    - image.style.huge
+    - image.style.large
+    - image.style.medium
+  module:
+    - breakpoint
+id: wide
+label: Wide
+image_style_mappings:
+  -
+    breakpoint_id: breakpoint.all.viewport_sizing
+    multiplier: 1x
+    image_mapping_type: sizes
+    image_mapping:
+      sizes: '(min-width: 1290px) 1290px, 100vw'
+      sizes_image_styles:
+        - gigantic
+        - huge
+        - large
+        - medium
+breakpoint_group: All Viewports
+fallback_image_style: medium
diff --git a/core/modules/responsive_image/src/Tests/ResponsiveImageAdminUITest.php b/core/modules/responsive_image/src/Tests/ResponsiveImageAdminUITest.php
index a3e2213..1218158 100644
--- a/core/modules/responsive_image/src/Tests/ResponsiveImageAdminUITest.php
+++ b/core/modules/responsive_image/src/Tests/ResponsiveImageAdminUITest.php
@@ -38,13 +38,18 @@ protected function setUp() {
    * Test responsive image administration functionality.
    */
   public function testResponsiveImageAdmin() {
-    // We start without any default styles.
+    // We start with two default styles.
     $this->drupalGet('admin/config/media/responsive-image-style');
-    $this->assertText('There is no Responsive image style yet.');
+    $this->assertNoText('There is no Responsive image style yet.');
+    $this->assertText('Narrow');
+    $this->assertText('narrow');
+    $this->assertText('Wide');
+    $this->assertText('wide');
 
     // Add a new responsive image style, our breakpoint set should be selected.
     $this->drupalGet('admin/config/media/responsive-image-style/add');
-    $this->assertFieldByName('breakpoint_group', 'responsive_image_test_module');
+    $this->assertFieldByName('breakpoint_group', 'All Viewports');
 
     // Create a new group.
     $edit = array(
@@ -110,7 +115,9 @@ public function testResponsiveImageAdmin() {
     $this->drupalGet('admin/config/media/responsive-image-style/style_one/delete');
     $this->drupalPostForm(NULL, array(), t('Delete'));
     $this->drupalGet('admin/config/media/responsive-image-style');
-    $this->assertText('There is no Responsive image style yet.');
+    $this->assertNoText('Style One');
+    // Default responsive image styles should remain.
+    $this->assertNoText('There is no Responsive image style yet.');
   }
 
 }
@@ -38,13 +38,18 @@ protected function setUp() {
 
-    // Add a new responsive image style, our breakpoint set should be selected.
+    // Add a new responsive image style, the all viewports breakpoint set should
+    // be selected.
     $this->drupalGet('admin/config/media/responsive-image-style/add');
